@@ -15,7 +15,8 @@
    You should have received a copy of the GNU Library General Public License
    along with this library; if not, see <http://www.gnu.org/licenses/>.
 
-/* Authors:   Callum McKenzie <callum@spooky-possum.org> */
+   Authors:   Callum McKenzie <callum@spooky-possum.org>
+*/
 
 #ifndef GAMES_FIND_FILE_H
 #define GAMES_FIND_FILE_H
