@@ -25,7 +25,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#include <libgames-support.h>
+#include <libgnome-games-support.h>
 
 #include "properties.h"
 #include "gameconfig.h"
@@ -72,7 +72,7 @@ struct _GnobotsProperties {
   gboolean show_toolbar;
   GdkRGBA bgcolour;
   gint selected_config;
-  gint keys[N_KEYS];
+  guint keys[N_KEYS];
   const gchar *themename;
 };
 /**********************************************************************/
@@ -275,7 +275,7 @@ sound_cb (GtkWidget * widget, gpointer data)
 static void
 defkey_cb (GtkWidget * widget, gpointer data)
 {
-  gint i;
+  guint i;
 
   for (i = 0; i < N_KEYS; ++i) {
     GVariant *variant;
@@ -284,7 +284,7 @@ defkey_cb (GtkWidget * widget, gpointer data)
     g_snprintf (buffer, sizeof (buffer), KEY_CONTROL_KEY, i);
     g_settings_reset (settings, buffer);
     variant = g_settings_get_default_value (settings, buffer);
-    properties.keys[i] = g_variant_get_int32 (variant);
+    properties.keys[i] = g_variant_get_uint32 (variant);
     g_variant_unref (variant);
   }
 
@@ -390,8 +390,9 @@ show_properties_dialog (void)
 
   propbox = gtk_dialog_new_with_buttons (_("Preferences"),
 					 GTK_WINDOW (window),
-					 GTK_DIALOG_USE_HEADER_BAR,
-					 NULL);
+					 GTK_DIALOG_USE_HEADER_BAR | GTK_DIALOG_MODAL,
+					 NULL,
+                                        NULL);
   gtk_container_set_border_width (GTK_CONTAINER (propbox), 5);
   gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (propbox))), 2);
   /* Set up notebook and add it to hbox of the gtk_dialog */
